# Specification

## Overview

The Button Toggle provides feedback of its pressed and unpressed state.

This specification is an extension of [SDS Button Toggle Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md)

## Use Cases

The button toggle enables an implementor to create a simple, but customizable button that toggles between a pressed and unpressed state.

## Non-goals

- Changing the text of the pressed state.

## Features

- The `pressed` state is reflected as an attribute on the host.
- The `pressed` state toggles the appropriate `aria` roles

## Prior Art/Examples

- [Salesforce Lightning Design System](https://www.lightningdesignsystem.com/components/buttons/)
- [Ant Design](https://ant.design/components/button/)
- [Atlassian](https://atlassian.design/components/button/examples)
- [Material Design](https://material.io/components/buttons)
- [Carbon](https://www.carbondesignsystem.com/components/button/usage/)
- [FAST](https://explore.fast.design/components/fast-button)
- [Morning Star](https://designsystem.morningstar.com/components/button/?version=3.1.4&tab=variations)
- [Polaris](https://polaris.shopify.com/components/actions/button)

---

## API

### Custom Element

This specification will apply to a WES subsystem ecosystem

wes-button-toggle - This is owned by WES Design System

## Anatomy and Appearance

The following DOM structure and named part attribute on the leaf node as documented is **required** to use the WES button toggle CSS.

### Diagram

[SDS Button Toggle - Diagram &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#diagram)

### DOM Structure

[SDS Button Toggle - DOM Structure &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#dom-structure)

### Properties & Attributes

[SDS Button Toggle - Properties & Attributes &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#properties--attributes)


### Events

[SDS Button Toggle - Events &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#events)

### Styling Hooks

N/A. Currently there is no customisation through styling hooks is being offered for the button-toggle.


## Behavior

### States & Interactions

[SDS Button Toggle - States & Interactions &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#states--interactions)


## Accessibility

[SDS Button Toggle - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#accessibility)


## Internationalization

[SDS Button Toggle - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#internationalization)

## Test Plan

[SDS Button Toggle - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button-toggle/button-toggle.spec.md#test-plan)

[button-spec]: https://html.spec.whatwg.org/multipage/form-elements.html#the-button-element
[anchor-spec]: https://html.spec.whatwg.org/multipage/text-level-semantics.html#the-a-element
[input-spec]: https://html.spec.whatwg.org/multipage/input.html#the-input-element
[input-button-spec]: https://html.spec.whatwg.org/multipage/input.html#button-state-(type=button)
[input-submit-spec]: https://html.spec.whatwg.org/multipage/input.html#submit-button-state-(type=submit)
[css-shadow-parts]: https://drafts.csswg.org/css-shadow-parts/
[styling-hooks-jump]: #styling-hooks
[namespace-service]: https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-namespaces/src/namespaces.js